#!/bin/bash

# this script creates a keystore.jks and keystore.p12 which contains all of:
# the private key (key*.pem), the corresponding certificate (cert.pem)
# and the certificate chain (ca-chain.pem)

if [[ $# -ne 1 ]] ; then
    echo ""
    echo "completes a keystore deployment"
    echo ""
    echo 'arguments: <keyStoreName>'
    echo ''
    exit 1
fi

name=$1
path='/var/opt/keys/own/'${name}

if [[ ! -s ${path}/key_pkcs1.pem ]]; then
    echo "key_pkcs1.pem not found"
    exit 2
fi

if [[ ! -s ${path}/cert.pem ]]; then
    echo "cert.pem not found"
    exit 3
fi

if [[ -s ${path}/keypass.sh ]]; then
    echo "migrating keypass.sh to keypass"
    cp ${path}/keypass.sh ${path}/keypass
fi

if [ ! -s ${path}/keypass ]; then
    echo "generating a new password"
    password=`cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 32 | head -n 1`
    echo "echo \"$password\"" > ${path}/keypass
fi

echo "ensure permissions are correct for keypass"
chown root:nvbgroup ${path}/keypass
chmod ug+x ${path}/keypass

password=`${path}/keypass`

echo "re-creating PKCS12 keystore ($path/keystore.p12)"

openssl pkcs12 -export -out ${path}/keystore.p12 -inkey ${path}/key_pkcs1.pem -in ${path}/cert.pem -password pass:${password}

if [ ! -s ${path}/keystore.p12 ]; then
    echo "keystore.p12 not found"
    exit 4
fi

echo "re-creating PEM keystore ($path/keystore.pem)"

cat ${path}/key_pkcs1.pem ${path}/cert.pem > ${path}/keystore.pem

# keytool does not overwrite so we delete first
rm ${path}/keystore.jks

if [[ -f ${JAVA_HOME}/bin/keytool ]]; then
    echo "found via JAVA_HOME"
    KEYTOOL=${JAVA_HOME}/bin/keytool
elif [[ `command -v keytool` ]]; then
    echo "found via PATH"
    KEYTOOL=keytool
else
    echo "fallback to adnjdk18"
    KEYTOOL=/opt/adnjdk18/bin/keytool
fi

echo "re-creating JKS keystore ($path/keystore.jks)"

${KEYTOOL} -noprompt -importkeystore \
  -srckeystore ${path}/keystore.p12 -srcstoretype pkcs12 -srcstorepass ${password} \
  -destkeystore ${path}/keystore.jks -deststoretype jks -deststorepass ${password}
