#!/bin/bash

if [[ $# -ne 1 ]] ; then
    echo ""
    echo "completes a truststore deployment"
    echo ""
    echo 'arguments: <trustStoreName>'
    echo ''
    exit -1
fi

name=$1
path='/var/opt/keys/trust/'${name}

pem_file=${path}/truststore.pem

if [[ ! -s ${pem_file} ]]; then
    echo "$pem_file not found"
    exit 1
fi

# TODO koenig 20180706: cleanup password catch 22
# - we have to use keytool as pkcs12 files produced by openssl are not compatible with SunJSSE provider
# - keytool cannot create a keystore file without a password
# - password is also required to load truststore.p12 from Java (but not for JKS)
# - in nevisAuth this password has to be defined as system property
# - system properties are defined in conf/env.conf
# - env.conf is loaded by systemd as EnvironmentFile
# - EnvironmentFile does not support expressions so we cannot use a passphrase getter
# - therefore the password has to be hard-coded here and in env.conf
password=password

echo "echo \"$password\"" > ${path}/keypass
chown root:nvbgroup ${path}/keypass
chmod ug+x ${path}/keypass

# number of certs in the import PEM file
certs=$(grep 'END CERTIFICATE' ${pem_file}| wc -l)

p12_file=${path}/truststore.p12
jks_file=${path}/truststore.jks

# keytool does not overwrite therefore we first delete the existing truststore.* files
\rm ${p12_file}
\rm ${jks_file}

if [[ -f ${JAVA_HOME}/bin/keytool ]]; then
    echo "found via JAVA_HOME"
    KEYTOOL=${JAVA_HOME}/bin/keytool
elif [[ `command -v keytool` ]]; then
    echo "found via PATH"
    KEYTOOL=keytool
else
    echo "fallback to adnjdk18"
    KEYTOOL=/opt/adnjdk18/bin/keytool
fi

# for every cert in the PEM file, extract it and import into the keystore
# awk command: step 1, if line is in the desired cert, print the line
#              step 2, increment counter when last line of cert is found
for N in $(seq 0 $(($certs - 1))); do

  alias="${pem_file%.*}-$N"

  cat ${pem_file} | awk "n==$N { print }; /END CERTIFICATE/ { n++ }" |
  ${KEYTOOL} -noprompt -import -trustcacerts -alias ${alias} \
  -keystore ${p12_file} -storepass ${password} -storetype PKCS12

  cat ${pem_file} | awk "n==$N { print }; /END CERTIFICATE/ { n++ }" |
  ${KEYTOOL} -noprompt -import -trustcacerts -alias ${alias} \
  -keystore ${jks_file} -storepass ${password} -storetype JKS
done
