#!/bin/bash

if [[ $# -ne 3 ]] ; then
    echo ""
    echo "validates a keystore"
    echo ""
    echo 'arguments: <keystoreName> <cn> <fail>'
    echo ''
    exit -1
fi

name=$1
cn=$2
fail=$3

path='/var/opt/keys/own/'${name}

if [[ "$fail" == "true" ]]; then
  exit 1
fi

if [ ! -d "${path}" ]; then
  echo "keystore ${path} does not exist"
  exit 2
fi

if [ ! -f "${path}/key_pkcs1.pem" ]; then
  echo "private key ${path}/key_pkcs1.pem does not exist"
  exit 3
fi

if [ ! -f "${path}/key_pkcs8.pem" ]; then
  echo "private key ${path}/key_pkcs8.pem does not exist"
  exit 4
fi

if [ ! -f "${path}/key_pub.pem" ]; then
  echo "public key ${path}/key_pub.pem does not exist"
  exit 5
fi

if [ ! -f "${path}/cert.pem" ]; then
  echo "certificate ${path}/cert.pem does not exist"
  exit 6
fi

key_hash=`openssl x509 -noout -modulus -in ${path}/cert.pem | openssl md5`
cert_hash=`openssl rsa -noout -modulus -in ${path}/key_pkcs1.pem | openssl md5`

if [ "$key_hash" != "$cert_hash" ]; then
  echo "private key does not match certificate"
  exit 7
fi

if [ -f "${path}/ca-chain.pem" ]; then
  openssl verify -CAfile ${path}/ca-chain.pem ${path}/cert.pem
  if [ "$?" != "0" ]; then
    echo "CA chain is not valid for certificate"
    exit 8
  fi
fi

# TODO koenig 20180822: validate CN
