# This is a shell script template, for use by InstanceUtil. It will not execute as expected when run directly.

# Parameters of this template (to be replaced before execution):
#  ${instanceFile}  -> the location of the instance yml of the instance (may not exist yet), this used to get the pid of the instance, if it is running
#  ${ports}         -> the ports to check of availability, formatted as '"host:port" "host:port" ..'

# a shell script template, can be a one-liner if new-lines are removed
if [ -r "${instanceFile}" ]; then                                                              # if instance file exists ..
    pidExtract=`grep pid ${instanceFile}`;                                                     # .. grep the line with the pid expression out of it
    pidExtract=${pidExtract%\"};                                                               # .. remove quote from end of the line
    pidCommand=${pidExtract##*:* \"};                                                          # .. remove prefix to get pid command expression
    [[ $pidCommand = file://* ]] && pid=`cat ${pidCommand#file://}` || pid=`eval $pidCommand`; # .. read pid from file or execute command to get it
fi;

failed=0;
for port in ${ports}; do                                                                       # for each port ..
  occupants=`lsof -R -i@$port | grep LISTEN | grep -v " ${pid:-99999999} "`;                   # .. ask lsof who uses the port, filter out pid of instance if there was one (use a ridiculous number as fallback)
                                                                                               #    note on -R flag for lsof: both parent and child processes of nevisproxy hold file descriptors for the ports

  if [ ! -z "$occupants" ]; then                                                               # if there were any occupants that did not have the expected pid..
     echo "port $port occupied:";
     echo "$occupants";
     failed=1;                                                                                 # .. mark failure if there were occupants
  fi;
done;

[ $failed == 0 ]                                                                               # trigger overall failure if there were occupants