#!/bin/bash

# remember current position in log
BYTES=$(stat -c "%s" /var/opt/nevisauth/${instance}/log/esauth4sv.log || echo 0)

sudo systemctl restart nevisauth@${instance}

# wait at most 20 seconds for the log to appear
for counter in {1..20}
do
    [[ -f /var/opt/nevisauth/${instance}/log/esauth4sv.log ]] && break
    [[ ${counter} -eq 20 ]] && echo "timeout (20s) reached waiting for nevisAuth log." && exit 1
    sleep 1
done

# wait at most 60 seconds for status message in log
timeout 60 awk '/Authentication services initialized/{print; exit 0} /Authentication services initialization failed/{print; exit 1}' <(tail --silent -f /var/opt/nevisauth/${instance}/log/esauth4sv.log --bytes=+$((BYTES+1)))
RC=$?
if [[ ${RC} -eq 124 ]]
then
    echo "timeout (60s) reached waiting for nevisAuth startup."
    exit 2
fi

# wait at most 20 seconds for the port to be open
timeout 20 bash -c 'until echo > /dev/tcp/${host}/${port}; do sleep 1; done'
if [[ $? -eq 0 ]]; then
    echo "UP: nevisAuth (https://${host}:${port})"
    exit 0
else
    echo "timeout (20s) reached waiting for nevisAuth (https://${host}:${port})"
    exit 1
fi