Enter `AuthState` elements as XML.

The `Domain` element is optional.

- If missing the element will be created. The `Entry` methods 
`authenticate` and `stepup` will be set to the first provided `AuthState`. 
The method `logout` is not set and thus the nevisAuth default behaviour applies.

- If provided the `Domain` must come before all `AuthState` elements. 
The attributes `name` and `default` are not supported and should be omitted.
Attributes are sorted by name. The `Entry` elements are sorted by `method`.

The `AuthState` linked to `stepup` should be able to dispatch the request.
For instance, you may have assigned an `Authorization Policy` to your application(s)
and thus you need a state which decides based on the request variable `requiredRoles`.

The following example dispatches level `2` into an `AuthState` named `TAN`
which provides authentication via mTAN:

```
<AuthState name="EntryDispatcher" class="ch.nevis.esauth.auth.states.standard.ConditionalDispatcherState" final="false">
    <ResultCond name="nomatch" next="Authentication_Done"/>
    <ResultCond name="level2" next="TAN"/> <!-- TAN state must set authLevel="2" -->
    <Response value="AUTH_ERROR">
        <Arg name="ch.nevis.isiweb4.response.status" value="403"/>
    </Response>
    <property name="condition:level2" value="${request:requiredRoles:^2.*$:true}"/>
</AuthState>
```

The following expressions are supported:

- `${instance}`: name of the nevisAuth instance
- `${request_url}`: generates a nevisAuth expression which returns the URL of the current request
- `${realm}`: name of the Realm (see below)
- `${service_url}`: generates a nevisAuth expression which evaluates to true for requests received on the configured `Frontend Path`
- `${keystore}`: name of the `KeyStore` element provided by this pattern. Assign a pattern to `Key Objects` to add a `KeyObject` into this `KeyStore`. 

The `name` of `AuthState` elements is prefixed 
with the sanitized name of the Realm (referred to as `${realm}`).

The realm prefix must be added when using `propertyRef` to reference AuthStates
generated by other patterns (e.g. `<propertyRef name="${realm}_SomeState"/>`).

An exception is the AuthState which defines the nevisIDM connection 
(as generated by `nevisIdm Password Login` or `nevisIDM Connector for Generic Authentication`).
Here the `propertyRef` must be defined as follows: 

`<propertyRef name="nevisIDM_Connector"/>`

This pattern does not validate that labels are translated.
Translations can be provided on the `Authentication Realm` pattern.