By default the Service Provider does not need any rendering template.

A GUI will be shown only when `Logout Reminder` is `enabled`
and but may also be shown when `Custom Pre-Processing` is used.

### nevisLogrend: Simple Mode

Point your browser to a protected application to have a look at the login page.
Download any resources (e.g. images, CSS) that you want to adapt. 
Then upload the changed files here.

In order to change the outer HTML upload a file named `template.html`. Here is a simple example:

```html
<!DOCTYPE html>
<html lang="${lang.code}">
  <head>
    <title>${label.title}</title>
    <link href="${resources}/bootstrap.min.css" rel="stylesheet" type="text/css">
    <link href="${resources}/default.css" rel="stylesheet" type="text/css" media="all">
  </head>
  <body>
    <header id="header" class="container-fluid">
      <img class="logo center-block" src="${resources}/example.svg" alt="NEVIS Security Suite">
    </header>
    <main id="content" class="container">
      ${form}
    </main>
  </body>
</html>
```

Please also upload file resources referenced by your template (e.g. images, CSS, Javascript). 
Use this when you reference additional files, or if you want to override the default files provided. 

The template must contain `${form}` and may contain additional expressions.

| Expression | Description | 
|---|---|
| `${form}` | generated login form (required) |
| `${lang.switch}` | language switcher component |
| `${lang.code}` | current language code (i.e. EN, DE) |
| `${label.title}` | a human-readable title |
| `${label.myLabel}` | a custom text which must be defined via `Custom Translations` |
| `${resources}` | path to static resources (e.g. CSS, images, Javascript) |

Some resources (i.e. bootstrap.min.css, default.css) are provided out of the box
because they are required by the default template. Feel free to use them.

### nevisLogrend: Expert Mode

Expert users may upload Velocity templates and resources to nevisLogrend.

Zip files will be extracted into the nevisLogrend *application*:

`/var/opt/nevislogrend/<instance>/data/applications/<realm>`

Flat files will be added to the following sub-directories:

-  `webdata/template`: Velocity templates (`*.vm`)
-  `webdata/resources`: additional resources (e.g. images, CSS)

### nevisProxy: Simple Template

nevisProxy also provides a simple login page renderer.

For each enabled language (e.g. `en`) upload a file named `<lang>_template.html`.
The template must contain the placeholder `NEVIS_AUTH_FORM`. 

If your templates require additional resources (e.g. CSS, images)
upload them as `Hosted Resources` on the nevisProxy virtual host.
