def getRequiredLevel(i2l, String issuer) {
    // determine required level based on request (SP-initiated)
    def context = session.get('ch.nevis.auth.saml.request.authnContextClassRef')
    if (context != null && context.startsWith('urn:nevis:level:')) {
        def levels = context.substring(16)
        String candidate = levels.contains(',') ? levels.split(',').min() : levels
        if (!candidate.isNumber()) {
            LOG.info("unable to determine required authentication level from authnContextClassRef: $context -> $candidate")
        }
        else {
            return candidate
        }
    }
    if (i2l.containsKey(issuer)) {
        return i2l.get(issuer)
    }
    else {
        LOG.error("required authentication level for issuer $issuer is not defined")
    }
    return null
}

def dispatch(String level) {
    if (response.getActualRoles().contains(level)) {
        response.setResult('done')
        return
    }
    request.setRequiredRoles(level)
    def method = request.getMethod()
    response.setResult(method)
}

def i2l = [:]
def value = parameters.get("levels")
if (!value.isEmpty()) {
    value.split(',').each {
        def kv = it.split("=")
        def issuer = kv[0]
        def level = kv[1]
        i2l.put(issuer, level)
    }
}

// determine required level based on configuration (SP-initiated)
def issuer = session.get('ch.nevis.auth.saml.request.issuer')

def level = getRequiredLevel(i2l, issuer)

if (level == null) {
    LOG.info("unable to determine required authentication level for issuer $issuer")
    response.setResult('done')
    return
}

dispatch(level)