def getReferer(request) {
    def inctx = request.getLoginContext()
    def key = 'connection.HttpHeader.Referer'
    return inctx.containsKey(key) ? inctx.get(key) : '/'
}

def redirect(location) {
    outargs.put('nevis.transfer.type', 'redirect')
    outargs.put('nevis.transfer.destination', location)
}

def dispatchIssuer(i2s, String issuer) {
    def result = i2s.get(issuer)
    response.setResult(result)
    // remember decision for sub-sequent requests without a SAML message
    session.put('saml.idp.result', result)
}

def dispatch(i2s, String key) {
    def value = inargs.get(key)
    def decoded = new String(value.decodeBase64())
    def xml = new XmlSlurper().parseText(decoded)
    // according to the SAML spec Issuer is optional but we need it for dispatching
    def issuer = xml.Issuer.text()
    dispatchIssuer(i2s, issuer)
}

if (request.getSession(false) == null) {
    session = request.getSession(true).getData();
}

def method = request.getMethod()
if ("authenticate" == method) {
    if (inargs.isEmpty()) {
        // accessing the IDP without session -> redirect to referer or /
        def location = getReferer(request)
        redirect(location)
        return
    }
}
else if ("stepup" == method) {
    def resource = request.getCurrentResource()
    def url = new URL(resource)
    def path = url.getPath()
    if (path.endsWith("/logout")) {
        // next AuthState shows logout confirmation GUI
        response.setResult('confirm')
        return
    }
}

def i2s = [:]
${entries}

if (inargs.containsKey('SAMLRequest')) {
    dispatch(i2s, 'SAMLRequest')
}
else if (inargs.containsKey('SAMLResponse')) {
    dispatch(i2s, 'SAMLResponse')
}
else if (inargs.containsKey('Issuer')) {
    dispatchIssuer(i2s, inargs.get('Issuer'))
}
// used when there is no incoming SAML message and case of ?logout
else if (session.containsKey('saml.idp.result')) {
    def result = session.get('saml.idp.result')
    response.setResult(result)
}

// ensure the IdentityProviderState Content have a similar state
def keys = []
def merged = [:]

session.each { k, v ->
    if (k.endsWith("-session-participants")) {
        keys.add(k)
        merged.putAll(v)
    }
}

keys.each { k ->
    session.put(k, merged)
}