// if any of the required roles is already achieved
// then we can terminate this stepup early
// this is a work-around for SecurityRoleFilter
// which does not notice that the stepup process ends with AUTH_DONE on a different location (acs path)
request.requiredRoles.each { role ->
    if (response.actualRoles.contains(role)) {
        response.setResult('done')
        return
    }
}

if (inargs.containsKey('SAMLResponse')) {
    // consume SAML response
    LOG.debug('received SAML response')
    return
}

if (session.containsKey('force-saml-authn')) {
    LOG.debug('clearing force-saml-authn flag')
    // clear marker
    session.remove('force-saml-authn')
    // redirect back to application if on ACS URL
    if (inargs.containsKey('relayState')) {
        def relayState = inargs.get('relayState')
        LOG.debug("user will be redirect to $relayState after successful validation")
        outargs.put('nevis.transfer.destination', relayState)
    }
    return
}

def requiredRoles = request.getRequiredRoles()

// stepup location
if (requiredRoles == null || requiredRoles.length == 0) {
    if (inargs.containsKey('level')) {
        def level = inargs.get('level')
        LOG.debug("requested authentication level $level")
        String[] roles = [ level ]
        request.setRequiredRoles(roles)
    }
    else {
        LOG.debug('no authentication level requested')
        // set a dummy role which never exists
        // to force the SP to send an AuthnRequest to the IDP
        String[] roles = ['dummy']
        request.setRequiredRoles(roles)
    }
}
// stepup triggered by SecurityRoleFilter
else if (requiredRoles.length > 1) {
    def level = requiredRoles.min()
    LOG.debug("required minimum authentication level: $level")
    String[] roles = [ level ]
    request.setRequiredRoles(roles)
}

LOG.debug('setting force-saml-authn')
session.put('force-saml-authn', 'true')