Enter `AuthState` elements as XML.

Here is a simple example to illustrate the syntax:

```xml
<AuthState 
  name="${state.entry}"
  class="ch.nevis.esauth.auth.states.standard.ThrottleSessionsState"
  final="false">
  <ResultCond name="ok" next="${state.done}" />
  <Response value="AUTH_ERROR">
    <Gui name="AuthErrorDialog"/>
  </Response>
  <property name="queryValue" value="${request:userId}" />
</AuthState>
```  

See [Standard authentication AuthStates and plug-ins](https://clientconnect.adnovum.net/nevisdoc/display/NEVISAUTHDOC05/Standard+authentication+AuthStates+and+plug-ins) for further examples. 

The following expressions are supported:

- `${instance}`: name of the nevisAuth instance.
- `${request_url}`: generates a nevisAuth expression which returns the URL of the current request
- `${realm}`: name of the Realm (see below)
- `${state.entry}`: use as `name` to mark the first `AuthState`.
- `${state.done}`: use as `next` in `ResultCond` elements to exit this step and continue with `On Success`.
- `${state.failed}`: use as `next` in `ResultCond` elements to exit this step and continue with `On Failure`.
- `${state.exit.<index>}`: use as `next` in `ResultCond` elements to exit this step and continue with an `Additional Follow-up Step(s)`. The index starts with `1`.
- `${state.level}`: must be used if an `Authentication Level` has been defined. Use as `authLevel` on `ResultCond` elements which point to `${state.done}`.
- `${keystore}`: name of the `KeyStore` element provided by this pattern. Assign a pattern to `Key Objects` to add a `KeyObject` into this `KeyStore`. 

The `name` of `AuthState` elements is prefixed 
with the sanitized name of the Realm (referred to as `${realm}`).

The realm prefix must be added when using `propertyRef` to reference AuthStates
generated by other patterns (e.g. `<propertyRef name="${realm}_SomeState"/>`).

An exception is the add-on pattern `nevisIDM Connector for Generic Authentication` which does not set a prefix.
Here the `propertyRef` must be defined as follows: 

`<propertyRef name="nevisIDM_Connector"/>`

This pattern does not validate that labels are translated.
Translations can be provided on the `Authentication Realm` pattern.