Configure `servlet` and/or `servlet-mapping` elements
using the XML constructs described in the nevisProxy Technical Documentation.

You may **add** new elements or **customize** elements provided by other patterns.

- Reference a `servlet` by setting `servlet-name`. Use `Connector_${service.name}`for the servlet which connects to the backend application.
- Reference a `servlet-mapping` by setting `url-pattern`.

Example 1: Add or overwrite an `init-param`:

Enable load-balancing when there are multiple backend servers.

```xml
<servlet>
  <servlet-name>Connector_${service.name}</servlet-name>
  <init-param>
    <param-name>LoadBalancing</param-name>
    <param-value>true</param-value>
  </init-param>
</servlet>
```

Instruct nevisProxy to a add `Content-Type` header when missing.

```xml
<servlet>
  <servlet-name>Connector_${service.name}</servlet-name>
  <init-param>
    <param-name>ProxyPolicy</param-name>
    <param-value>mime-completion</param-value>
  </init-param>
</servlet>
```

Example 2: Remove an `init-param` (no `param-value` provided):

```xml
<servlet>
  <servlet-name>Connector_${service.name}</servlet-name>
  <init-param>
    <param-name>CookieManager</param-name>
  </init-param>
</servlet>
```

Example 3: Change the `servlet-mapping` for an application to use a different servlet 
by changing `servlet-name`.

```xml
<servlet>
   <servlet-name>Connector_Conditional_${service.name}</servlet-name>
   <servlet-class>ch::nevis::isiweb4::servlet::mapping::ServletMappingServlet</servlet-class>
   ...
</servlet>
<servlet-mapping>
   <servlet-name>Connector_Conditional_${service.name}</servlet-name>
   <url-pattern>${service.path}/*</url-pattern>
</servlet-mapping>
```

Removing `servlet` or `servlet-mapping` elements is not supported.