function contains(tab, val)
    for index, value in ipairs(tab) do
        if value == val then
            return true
        end
    end
    return false
end

function inputHeader(request, response)

  if (request:getMethod() == "GET") then
    -- GET requests are not sensitive by assumption and thus not checked
    return
  end

  -- patterns sets allowed domains or {}
  domains = ${domains}

  host = request:getHeader("Host")

  if (host == nil) then
    -- Internet-based HTTP/1.1 servers MUST respond with a 400 (Bad Request) status code to any HTTP/1.1 request message which lacks a Host header field.
    request:getTracer():notice("VA05", "Missing Host header")
    response:setHeader("Content-Type", "text/plain")
    response:setBody("400 Bad Request")
    response:send(400)
    return
  end

  -- extract host name
  host = host:match('([^:]+)')

  referer = request:getHeader("Referer")
  if (referer ~= nil) then
    referer = referer:match('^%w+://([^/:]+)')
    if (referer ~= host and not contains(domains, referer)) then
        request:getTracer():notice("VA01", "HTTP Referer header " .. referer .. " does not match host " .. host)
        response:setHeader("Content-Type", "text/plain")
        response:setBody("403 Denied")
        response:send(403)
        return
    end
  end

  origin = request:getHeader("Origin")
  if (origin ~= nil) then
    origin = origin:match('^%w+://([^/:]+)')
    if (origin ~= host and not contains(domains, referer)) then
        request:getTracer():notice("VA01", "HTTP Origin header " .. origin .. " does not match host " .. host)
        response:setHeader("Content-Type", "text/plain")
        response:setBody("403 Denied")
        response:send(403)
        return
    end
  end

  if (origin == nil and referer == nil) then
    request:getTracer():info("VA05", "Referer or Origin header is required for non-GET requests")
    response:setHeader("Content-Type", "text/plain")
    response:setBody("403 Denied")
    response:send(403)
    return
  end
end